# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class UIPage(Component):
    """An UIPage component.
ExampleComponent is an example component.
It takes a property, `label`, and
displays it.
It renders an input with the property `value`
which is editable by the user.

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): Children
- id (string; optional): Element id
- name (string; required): Page name
- value (string; required)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, name=Component.REQUIRED, value=Component.REQUIRED, **kwargs):
        self._prop_names = ['children', 'id', 'name', 'value']
        self._type = 'UIPage'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'name', 'value']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['name', 'value']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(UIPage, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
Carbon Button

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): Specify the content of your Button
- id (string; required): The id of the button
- style (dict; optional): jsx Style
- className (string; optional): Specify an optional className to be added to your Button
- disabled (boolean; optional): Specify whether the Button should be disabled, or not
- dangerDescription (string; optional): Specify the message read by screen readers for the danger button variant
- href (string; optional): Optionally specify an href for your Button to become an `<a>` element
- isSelected (boolean; optional): Specify whether the Button is currently selected
- kind (a value equal to: 'primary', 'secondary', 'danger', 'ghost', 'danger--primary', 'danger--ghost', 'danger--tertiary', 'tertiary'; required): Specify the kind of Button you want to create
- role (string; optional): Optional prop to specify the role of the Button
- size (a value equal to: 'default', 'field', 'small', 'sm', 'lg', 'xl'; optional): Specify the size of the button, from a list of available sizes.
For `default` buttons, this prop can remain unspecified.
- tooltipAlignment (a value equal to: 'start', 'center', 'end'; optional): Specify the alignment of the tooltip to the icon-only button.
Can be one of: start, center, or end.
- tooltipPosition (a value equal to: 'top', 'right', 'bottom', 'left'; optional): Specify the direction of the tooltip for icon-only buttons.
Can be either top, right, bottom, or left.
- type (a value equal to: 'button', 'reset', 'submit'; optional): Optional prop to specify the type of the Button
- n_clicks (number; default 0): Number of times this button has been clicked"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.REQUIRED, style=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, dangerDescription=Component.UNDEFINED, href=Component.UNDEFINED, isSelected=Component.UNDEFINED, kind=Component.REQUIRED, role=Component.UNDEFINED, size=Component.UNDEFINED, tooltipAlignment=Component.UNDEFINED, tooltipPosition=Component.UNDEFINED, type=Component.UNDEFINED, n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'style', 'className', 'disabled', 'dangerDescription', 'href', 'isSelected', 'kind', 'role', 'size', 'tooltipAlignment', 'tooltipPosition', 'type', 'n_clicks']
        self._type = 'Button'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'style', 'className', 'disabled', 'dangerDescription', 'href', 'isSelected', 'kind', 'role', 'size', 'tooltipAlignment', 'tooltipPosition', 'type', 'n_clicks']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'kind']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NumberInput(Component):
    """A NumberInput component.
NumberInput component

Keyword arguments:
- allowEmpty (boolean; default False): `true` to allow empty string.
- style (dict; optional): style of the input
- ariaLabel (string; default 'Numeric input field with increment and decrement buttons'): Provide a description that would be used to best describe the use case of the NumberInput component
- className (string; optional): Specify an optional className to be applied to the wrapper node
- defaultValue (number | string; optional): Optional starting value for uncontrolled state
- disabled (boolean; default False): Specify if the control should be disabled, or not
- helperText (string; default ''): Provide text that is used alongside the control label for additional help
- hideLabel (boolean; default False): Specify whether you want the underlying label to be visually hidden
- iconDescription (string; default 'choose a number'): Provide a description for up/down icons that can be read by screen readers
- id (string; required): Specify a custom `id` for the input
- invalid (boolean; default False): Specify if the currently value is invalid.
- invalidText (string; default 'Provide invalidText'): Message which is displayed if the value is invalid.
- label (string; optional): Generic `label` that will be used as the textual representation of what
this field is for
- light (boolean; default False): `true` to use the light version.
- max (number; optional): The maximum value.
- min (number; optional): The minimum value.
- readOnly (boolean; optional): Specify if the component should be read-only
- size (a value equal to: 'sm', 'xl'; optional): Specify the size of the Number Input. Currently supports either `sm` or `xl` as an option.
- step (number; default 1): Specify how much the valus should increase/decrease upon clicking on up/down button
- value (number | string; optional): Specify the value of the input
- warn (boolean; default False): Specify whether the control is currently in warning state
- warnText (string; default ''): Provide the text that is displayed when the control is in warning state"""
    @_explicitize_args
    def __init__(self, allowEmpty=Component.UNDEFINED, style=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, className=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, helperText=Component.UNDEFINED, hideLabel=Component.UNDEFINED, iconDescription=Component.UNDEFINED, id=Component.REQUIRED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, label=Component.UNDEFINED, light=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, readOnly=Component.UNDEFINED, size=Component.UNDEFINED, step=Component.UNDEFINED, value=Component.UNDEFINED, warn=Component.UNDEFINED, warnText=Component.UNDEFINED, **kwargs):
        self._prop_names = ['allowEmpty', 'style', 'ariaLabel', 'className', 'defaultValue', 'disabled', 'helperText', 'hideLabel', 'iconDescription', 'id', 'invalid', 'invalidText', 'label', 'light', 'max', 'min', 'readOnly', 'size', 'step', 'value', 'warn', 'warnText']
        self._type = 'NumberInput'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['allowEmpty', 'style', 'ariaLabel', 'className', 'defaultValue', 'disabled', 'helperText', 'hideLabel', 'iconDescription', 'id', 'invalid', 'invalidText', 'label', 'light', 'max', 'min', 'readOnly', 'size', 'step', 'value', 'warn', 'warnText']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(NumberInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Slider(Component):
    """A Slider component.
Slider

Keyword arguments:
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- name (string; optional): Form item name
- inputType (string; default 'number'): The form element type
- ariaLabelInput (string; default ''): The ARIA label for the <input>
- labelText (string; required): Label text
- disabled (boolean; default False): Disabled
- light (boolean; default False): Light variant
- hideTextInput (boolean; default False): Without text input
- value (number; required): The value
- min (number; required): The minimum value
- max (number; required): The maximum value
- step (number; required): The step
- stepMultiplier (number; default 5): The step factor for Shift+arrow keys"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, name=Component.UNDEFINED, inputType=Component.UNDEFINED, ariaLabelInput=Component.UNDEFINED, labelText=Component.REQUIRED, disabled=Component.UNDEFINED, light=Component.UNDEFINED, hideTextInput=Component.UNDEFINED, value=Component.REQUIRED, min=Component.REQUIRED, max=Component.REQUIRED, step=Component.REQUIRED, stepMultiplier=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'name', 'inputType', 'ariaLabelInput', 'labelText', 'disabled', 'light', 'hideTextInput', 'value', 'min', 'max', 'step', 'stepMultiplier']
        self._type = 'Slider'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'name', 'inputType', 'ariaLabelInput', 'labelText', 'disabled', 'light', 'hideTextInput', 'value', 'min', 'max', 'step', 'stepMultiplier']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['labelText', 'value', 'min', 'max', 'step']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Slider, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MultiSelectFilterable(Component):
    """A MultiSelectFilterable component.
MultiSelect

Keyword arguments:
- disabled (boolean; optional): Disable the control
- style (dict; optional)
- locale (string; optional): Specify the locale of the control.
Used for the default compareItems used for sorting the list of items in the control.
- light (boolean; optional): true to use the light version.
- selectionFeedback (a value equal to: 'top', 'fixed', 'top-after-reopen'; optional): Specify feedback (mode) of the selection.
top: selected item jumps to top
fixed: selected item stays at it's position
top-after-reopen: selected item jump to top after reopen dropdown
default top-after-reopen
- direction (a value equal to: 'bottom, top'; optional): Specify the direction of the multiselect dropdown. Can be either top or bottom.
default bottom
- id (string; required): Id of the element
- invalid (boolean; optional): Is the current selection invalid.
- invalidText (string; optional): The text to show if it is invalid.
- options (dict; required): List of items. options has the following type: list of string | dict containing keys 'label', 'value'.
Those keys have the following types:
  - label (string; optional)
  - value (boolean | number | string | dict | list; optional)s
- label (string; optional): Generic label that will be used as the textual representation of what this field is for
- size (a value equal to: 'sm', 'lg', 'xl'; optional): Specify the size of the ListBox. Currently supports either sm, lg or xl as an option.
- titleText (string; optional): Provide text to be used in a <label> element that is tied to the multiselect via ARIA attributes.
- value (list of boolean | number | string | dict | lists; optional): The list of the selected items"""
    @_explicitize_args
    def __init__(self, disabled=Component.UNDEFINED, style=Component.UNDEFINED, locale=Component.UNDEFINED, light=Component.UNDEFINED, selectionFeedback=Component.UNDEFINED, direction=Component.UNDEFINED, id=Component.REQUIRED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, options=Component.REQUIRED, label=Component.UNDEFINED, size=Component.UNDEFINED, titleText=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['disabled', 'style', 'locale', 'light', 'selectionFeedback', 'direction', 'id', 'invalid', 'invalidText', 'options', 'label', 'size', 'titleText', 'value']
        self._type = 'MultiSelectFilterable'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['disabled', 'style', 'locale', 'light', 'selectionFeedback', 'direction', 'id', 'invalid', 'invalidText', 'options', 'label', 'size', 'titleText', 'value']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'options']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(MultiSelectFilterable, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DatePicker(Component):
    """A DatePicker component.
DatePicker

Keyword arguments:
- allowInput (boolean; optional): flatpickr prop passthrough. Allows the user to enter a date directly
into the input field
- className (string; optional): The CSS class names.
- id (string; required): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- dateFormat (string; optional): The date format.
- light (boolean; optional): True to use the light version.
- locale (string; optional): The language locale used to format the days of the week, months, and numbers.
The full list of supported locales can be found here https://github.com/flatpickr/flatpickr/tree/master/src/l10n
- maxDate (string; optional): The maximum date that a user can pick to.
- minDate (string; optional): The minimum date that a user can start picking from.
- short (boolean; optional): True to use the short version.
- value (string | list of strings; optional): The value of the date value provided to flatpickr
- placeholder (string; required): Placeholder
- labelText (string; required): Label text"""
    @_explicitize_args
    def __init__(self, allowInput=Component.UNDEFINED, className=Component.UNDEFINED, id=Component.REQUIRED, dateFormat=Component.UNDEFINED, light=Component.UNDEFINED, locale=Component.UNDEFINED, maxDate=Component.UNDEFINED, minDate=Component.UNDEFINED, short=Component.UNDEFINED, value=Component.UNDEFINED, placeholder=Component.REQUIRED, labelText=Component.REQUIRED, **kwargs):
        self._prop_names = ['allowInput', 'className', 'id', 'dateFormat', 'light', 'locale', 'maxDate', 'minDate', 'short', 'value', 'placeholder', 'labelText']
        self._type = 'DatePicker'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['allowInput', 'className', 'id', 'dateFormat', 'light', 'locale', 'maxDate', 'minDate', 'short', 'value', 'placeholder', 'labelText']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'placeholder', 'labelText']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DatePicker, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioButtonGroup(Component):
    """A RadioButtonGroup component.
Radio Group Component

Keyword arguments:
- legendText (a list of or a singular dash component, string or number; optional): Provide a legend to the RadioButtonGroup input that you are
exposing to the user
- name (string; required): Specify the name of the underlying `<input>` nodes
- radiosButtons (dict; optional): The radios buttons inside this group. radiosButtons has the following type: list of dicts containing keys 'label', 'value', 'id'.
Those keys have the following types:
  - label (string; optional)
  - value (string; optional)
  - id (string; optional)
- id (string; optional): Specify a custom `id` for the radio group
- value (string; optional): The value selected
- labelPosition (a value equal to: 'left', 'right'; optional): Provide where label text should be placed
- orientation (a value equal to: 'horizontal', 'vertical'; optional): Provide where radio buttons should be placed
- disabled (boolean; optional): Specify whether the group is disabled
- className (string; optional): Provide an optional className to be applied to the container node"""
    @_explicitize_args
    def __init__(self, legendText=Component.UNDEFINED, name=Component.REQUIRED, radiosButtons=Component.UNDEFINED, id=Component.UNDEFINED, value=Component.UNDEFINED, labelPosition=Component.UNDEFINED, orientation=Component.UNDEFINED, disabled=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['legendText', 'name', 'radiosButtons', 'id', 'value', 'labelPosition', 'orientation', 'disabled', 'className']
        self._type = 'RadioButtonGroup'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['legendText', 'name', 'radiosButtons', 'id', 'value', 'labelPosition', 'orientation', 'disabled', 'className']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['name']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(RadioButtonGroup, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DatePickerInput(Component):
    """A DatePickerInput component.


Keyword arguments:
- id (string; required): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- disabled (boolean; optional): Specify whether or not the input should be disabled
- hideLabel (boolean; optional): Specify if the label should be hidden
- iconDescription (string; optional): The description of the calendar icon.
- invalid (boolean; optional): Specify whether or not the input should be invalid
- invalidText (string; optional): Specify the text to be rendered when the input is invalid
- labelText (string; required): Provide the text that will be read by a screen reader when visiting this control
- placeholder (string; optional): Specify the placeholder text
- size (a value equal to: 'sm', 'xl'; optional): Specify the size of the Date Picker Input. Currently supports either sm or xl as an option.
- warn (boolean; optional): Specify whether the control is currently in warning state
- warnText (string; optional): Provide the text that is displayed when the control is in warning state
- value (string; optional): Current value of the date
- datePickerType (a value equal to: 'range', 'single', 'simple'; optional): The type of the date picker"""
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, disabled=Component.UNDEFINED, hideLabel=Component.UNDEFINED, iconDescription=Component.UNDEFINED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, labelText=Component.REQUIRED, placeholder=Component.UNDEFINED, size=Component.UNDEFINED, warn=Component.UNDEFINED, warnText=Component.UNDEFINED, value=Component.UNDEFINED, datePickerType=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'disabled', 'hideLabel', 'iconDescription', 'invalid', 'invalidText', 'labelText', 'placeholder', 'size', 'warn', 'warnText', 'value', 'datePickerType']
        self._type = 'DatePickerInput'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'disabled', 'hideLabel', 'iconDescription', 'invalid', 'invalidText', 'labelText', 'placeholder', 'size', 'warn', 'warnText', 'value', 'datePickerType']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'labelText']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DatePickerInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Checkbox(Component):
    """A Checkbox component.
Checkbox Input

Keyword arguments:
- id (string; required): Provide an `id` to uniquely identify the Checkbox input
- label (a list of or a singular dash component, string or number; required): Provide a label to provide a description of the Checkbox input that you are
exposing to the user
- hideLabel (boolean; optional): Specify whether the label should be hidden, or not
- disabled (boolean; optional): Specify whether the Checkbox should be disabled
- value (boolean; optional): Specify whether the underlying input is checked
- title (string; optional): Specify a title for the <label> node for the Checkbox
- style (dict; optional): The inline styles
- className (string; optional): Specify an optional className to be applied to the <label> node"""
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, label=Component.REQUIRED, hideLabel=Component.UNDEFINED, disabled=Component.UNDEFINED, value=Component.UNDEFINED, title=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'label', 'hideLabel', 'disabled', 'value', 'title', 'style', 'className']
        self._type = 'Checkbox'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'label', 'hideLabel', 'disabled', 'value', 'title', 'style', 'className']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Checkbox, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tab(Component):
    """A Tab component.
Tab component

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): Tab content
- className (string; optional): Specify an optional className to be added to your Tab
- disabled (boolean; optional): Whether your Tab is disabled.
- label (string; required): Provide the contents of your Tab
- role (string; optional): Provide an accessibility role for your Tab
- value (string; optional): Value of the tab"""
    @_explicitize_args
    def __init__(self, children=None, className=Component.UNDEFINED, disabled=Component.UNDEFINED, label=Component.REQUIRED, role=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'className', 'disabled', 'label', 'role', 'value']
        self._type = 'Tab'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'className', 'disabled', 'label', 'role', 'value']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tab, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Tabs

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): Pass in a collection of <Tab> children to be rendered depending on the
currently selected tab
- ariaLabel (string; default 'listbox'): Specify the text to be read by screen-readers when visiting the <Tabs>
component
- style (dict; optional): Specify the inline style
- className (string; optional): Provide a className that is applied to the root <nav> component for the
<Tabs>
- hidden (boolean; optional): Specify whether the Tab content is hidden
- role (string; default 'navigation'): By default, this value is "navigation". You can also provide an alternate
role if it makes sense from the accessibility-side
- triggerHref (string; default '#'): Provide a string that represents the `href` for the triggered <Tab>
- selected (number; optional): Optionally provide an index for the currently selected <Tab>
- iconDescription (string; default 'show menu options'): Provide a description that is read out when a user visits the caret icon
for the dropdown menu of items
- tabContentClassName (string; optional): Provide a className that is applied to the <TabContent> components
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- headerOffsets (list of strings; optional): Number of columns of left offset the header will have
- headerSizes (list of strings; optional): Number of columns the header will have
- value (string; optional): Value of the selected tab"""
    @_explicitize_args
    def __init__(self, children=None, ariaLabel=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, hidden=Component.UNDEFINED, role=Component.UNDEFINED, onClick=Component.UNDEFINED, onKeyDown=Component.UNDEFINED, triggerHref=Component.UNDEFINED, selected=Component.UNDEFINED, iconDescription=Component.UNDEFINED, tabContentClassName=Component.UNDEFINED, id=Component.UNDEFINED, headerOffsets=Component.UNDEFINED, headerSizes=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'ariaLabel', 'style', 'className', 'hidden', 'role', 'triggerHref', 'selected', 'iconDescription', 'tabContentClassName', 'id', 'headerOffsets', 'headerSizes', 'value']
        self._type = 'Tabs'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'ariaLabel', 'style', 'className', 'hidden', 'role', 'triggerHref', 'selected', 'iconDescription', 'tabContentClassName', 'id', 'headerOffsets', 'headerSizes', 'value']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tabs, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Link(Component):
    """A Link component.
Link component

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): Provide the content for the Link
- id (string; optional): The id of the link
- style (dict; optional): Inline styles
- className (string; optional): Provide a custom className to be applied to the containing `<a>` node
- disabled (boolean; optional): Specify if the control should be disabled, or not
- inline (boolean; optional): Specify whether you want the inline version of this control
- size (a value equal to: 'sm', 'md', 'lg'; optional): Specify the size of the Link. Currently supports either `sm`, 'md' (default) or 'lg` as an option.
- n_clicks (number; default 0): Number of times this link has been clicked
- visited (boolean; default False): Specify whether you want the link to receive visited styles after the link has been clicked
- href (string; optional): Provide the `href` attribute for the `<a>` node"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, inline=Component.UNDEFINED, size=Component.UNDEFINED, n_clicks=Component.UNDEFINED, visited=Component.UNDEFINED, href=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'style', 'className', 'disabled', 'inline', 'size', 'n_clicks', 'visited', 'href']
        self._type = 'Link'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'style', 'className', 'disabled', 'inline', 'size', 'n_clicks', 'visited', 'href']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Link, self).__init__(children=children, **args)



from .Button import Button
from .Card import Card
from .Checkbox import Checkbox
from .Column import Column
from .DatePicker import DatePicker
from .DatePickerRange import DatePickerRange
from .Dropdown import Dropdown
from .Grid import Grid
from .Link import Link
from .MultiSelect import MultiSelect
from .NumberInput import NumberInput
from .RadioButtonGroup import RadioButtonGroup
from .Row import Row
from .Slider import Slider
from .Tab import Tab
from .Tabs import Tabs
from .UIShell import UIShell

__all__ = [
    "Button",
    "Card",
    "Checkbox",
    "Column",
    "DatePicker",
    "DatePickerRange",
    "Dropdown",
    "Grid",
    "Link",
    "MultiSelect",
    "NumberInput",
    "RadioButtonGroup",
    "Row",
    "Slider",
    "Tab",
    "Tabs",
    "UIShell"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Dropdown(Component):
    """A Dropdown component.
Dropdown component

Keyword arguments:
- disabled (boolean; optional): Disable the control
- options (dict; optional): List of items. options has the following type: list of string | dict containing keys 'label', 'value'.
Those keys have the following types:
  - label (string; optional)
  - value (boolean | number | string | dict | list; optional)s
- id (string; required): Specify a custom `id`
- inline (boolean; optional): Specify whether you want the inline version of this control
- invalid (boolean; optional): Specify if the currently selected value is invalid.
- invalidText (string; optional): Message which is displayed if the value is invalid.
- label (a list of or a singular dash component, string or number; required): Generic `label` that will be used as the textual representation of what
this field is for
- ariaLabel (string; optional): 'aria-label' of the ListBox component.
- value (boolean | number | string | dict | list; optional): In the case you want to control the dropdown selection entirely.
- light (boolean; optional): `true` to use the light version.
- titleText (string | a list of or a singular dash component, string or number; optional): Provide the title text that will be read by a screen reader when
visiting this control
- helperText (string | a list of or a singular dash component, string or number; optional): Provide helper text that is used alongside the control label for
additional help
- style (dict; optional): Style of the component"""
    @_explicitize_args
    def __init__(self, disabled=Component.UNDEFINED, options=Component.UNDEFINED, id=Component.REQUIRED, inline=Component.UNDEFINED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, label=Component.REQUIRED, translateWithId=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, value=Component.UNDEFINED, light=Component.UNDEFINED, titleText=Component.UNDEFINED, helperText=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['disabled', 'options', 'id', 'inline', 'invalid', 'invalidText', 'label', 'ariaLabel', 'value', 'light', 'titleText', 'helperText', 'style']
        self._type = 'Dropdown'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['disabled', 'options', 'id', 'inline', 'invalid', 'invalidText', 'label', 'ariaLabel', 'value', 'light', 'titleText', 'helperText', 'style']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id', 'label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Dropdown, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Row(Component):
    """A Row component.
Grid Row

Keyword arguments:
- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional): The children of the element
- style (dict; optional): The inline styles
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- className (string; default ''): The class of the element"""
    @_explicitize_args
    def __init__(self, children=None, style=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'style', 'id', 'className']
        self._type = 'Row'
        self._namespace = 'dash_carbon_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'style', 'id', 'className']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Row, self).__init__(children=children, **args)
